import { Router } from "express";
import {
  onboardEmployeeWithCreation,
  onboardEmployee,
  updatePersonalDetails,
  createVisaBrpData,
  updateVisaBrpData,
  getVisaBrpData,
  createEussData,
  updateEmpEussData,
  getEmpEussData,
  createEmpEducationData,
  updateEmpEducationData,
  deleteEmpEducationData,
  getEmpEducationData,
  createEmpContactInformationData,
  getContactInfoData,
  updatecontactInformationData,
  createNextOfKinData,
  CreateNIdInformationData,
  updateNidInformationData,
  getNidInfoData,
  getNextOfKinData,
  updateNextOfKinData,
  getEmpPassportData,
  createEmpPassportData,
  updateEmpPassportData,
  getAllDataOfEmployee,
  getPersonalDetails,
  getContactInfo,
  updatePersonalDetailsByEmployeeId,
  update_user_access_employee,
  getEmployeeReportPaginated,
  generateEmployeeReport,
  markEmployeesAsMigrants,
} from "../controllers/employee.controller";
import { authenticate } from "../middleware/auth.middleware";

const router = Router();

//employee/-->

router.post(
  "/admin/on-board-employee",
  authenticate,
  onboardEmployeeWithCreation
); // [x] Integration complete
router.post("/client/on-board-employee", authenticate, onboardEmployee);

// GET all of the user's data (personal, educational, passport, next of kin, ...)
router.get("/all-data/:employee_id", authenticate, getAllDataOfEmployee); //! Currently not in use, uses parallel routing to optimze performance

// GET personal data
router.get("/get-personal-data/:employee_id", authenticate, getPersonalDetails); // [x] Integration complete
// update personal data
router.patch("/update-personal-data", authenticate, updatePersonalDetails);
// update personal data [Super admin]
router.patch(
  "/update-personal-data/:employee_id",
  authenticate,
  updatePersonalDetailsByEmployeeId
); // [x] Integration complete

// get education data
router.get(
  "/get-education-data/:employee_id",
  authenticate,
  getEmpEducationData
); // [x] Integration complete
// create education data
router.post("/create-education-data", authenticate, createEmpEducationData); // [x] Integration complete
// update education data
router.patch("/update-education-data", authenticate, updateEmpEducationData); // [x] Integration complete
//delete education data
router.delete(
  "/delete-education-data/:education_id",
  authenticate,
  deleteEmpEducationData
);

//----------passport data
router.get("/get-passport-data/:employee_id", authenticate, getEmpPassportData); // [x] Integration complete

// create passport data
router.post("/create-passport-data", authenticate, createEmpPassportData); // [x] Integration complete
// update passport data
router.patch("/update-passport-data", authenticate, updateEmpPassportData); // [x] Integration complete

//----------Next Of kin  data
router.get("/get-next-kin-data/:employee_id", authenticate, getNextOfKinData); // [x] Integration complete
// create passport data
router.post("/create-next-kin-data", authenticate, createNextOfKinData); // [x] Integration complete
// update passport data
router.patch("/update-next-kin-data", authenticate, updateNextOfKinData); // [x] Integration complete

//----------visa/brp data------------

router.get("/get-visa-brp-data/:employee_id", authenticate, getVisaBrpData); // [x] Integration complete
// create passport data
router.post("/create-visa-brp-data", authenticate, createVisaBrpData); // [x] Integration complete
// update passport data
router.patch("/update-visa-brp-data", authenticate, updateVisaBrpData); // [x] Integration complete

//----------db /euss data------------

router.get("/get-euss-dbs-data/:employee_id", authenticate, getEmpEussData); // [x] Integration complete
// create passport data
router.post("/create-euss-dbs-data", authenticate, createEussData); // [x] Integration complete
// update passport data
router.patch("/update-euss-dbs-data", authenticate, updateEmpEussData); // [x] Integration complete

//----------contact info   data------------
// GET contact info
router.get("/get-contact-info/:employee_id", authenticate, getContactInfo); // [x] Integration complete

router.get("/get-contact-data/:employee_id", authenticate, getContactInfoData); //! Duplicate route of /get-contact-info/:employee_id
// create contact data
router.post(
  "/create-contact-data",
  authenticate,
  createEmpContactInformationData
); // [x] Integration Complete
// update contact data
router.patch(
  "/update-contact-data",
  authenticate,
  updatecontactInformationData
); // [x] Integration Complete

//----------NID  info   data------------

router.get("/get-nid-data/:employee_id", authenticate, getNidInfoData); // [x] Integration complete
// create contact data
router.post("/create-nid-data", authenticate, CreateNIdInformationData); // [x] Integration complete
// update contact data
router.patch("/update-nid-data", authenticate, updateNidInformationData); // [x] Integration complete

// update contact data
router.patch("/update-user-access", authenticate, update_user_access_employee); // [x] Integration complete

//----------------report
router.get("/report/:company_id", authenticate, generateEmployeeReport);
router.get(
  "/report/paginated/:company_id",
  authenticate,
  getEmployeeReportPaginated
);

// Mark multiple employees as migrant employee(s)
router.patch("/mark-as-migrant", authenticate, markEmployeesAsMigrants);

export default router;
